@@ -4,7 +4,7 @@
 
 import _mc4020
 
-def _swig_setattr(self,class_type,name,value):
+def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
     if (name == "this"):
         if isinstance(value, class_type):
             self.__dict__[name] = value.this
@@ -13,7 +13,13 @@ def _swig_setattr(self,class_type,name,value):
             return
     method = class_type.__swig_setmethods__.get(name,None)
     if method: return method(self,value)
-    self.__dict__[name] = value
+    if (not static) or hasattr(self,name) or (name == "thisown"):
+        self.__dict__[name] = value
+    else:
+        raise AttributeError("You cannot add attributes to %s" % self)
+
+def _swig_setattr(self,class_type,name,value):
+    return _swig_setattr_nondynamic(self,class_type,name,value,0)
 
 def _swig_getattr(self,class_type,name):
     method = class_type.__swig_getmethods__.get(name,None)
@@ -57,30 +63,67 @@ MCC_CLK_AD_START_TRIG_IN = _mc4020.MCC_CLK_AD_START_TRIG_IN
 MCC_ALL_1V = _mc4020.MCC_ALL_1V
 MCC_ALL_5V = _mc4020.MCC_ALL_5V
 class mc4020_source_sptr(_object):
+    """Proxy of C++ mc4020_source_sptr class"""
     __swig_setmethods__ = {}
     __setattr__ = lambda self, name, value: _swig_setattr(self, mc4020_source_sptr, name, value)
     __swig_getmethods__ = {}
     __getattr__ = lambda self, name: _swig_getattr(self, mc4020_source_sptr, name)
     def __repr__(self):
-        return "<C boost::shared_ptr<(mc4020_source)> instance at %s>" % (self.this,)
+        return "<%s.%s; proxy of C++ boost::shared_ptr<mc4020_source > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     def __init__(self, *args):
+        """
+        __init__(self) -> mc4020_source_sptr
+        __init__(self,  p) -> mc4020_source_sptr
+        """
         _swig_setattr(self, mc4020_source_sptr, 'this', _mc4020.new_mc4020_source_sptr(*args))
         _swig_setattr(self, mc4020_source_sptr, 'thisown', 1)
-    def __deref__(*args): return _mc4020.mc4020_source_sptr___deref__(*args)
-    def name(*args): return _mc4020.mc4020_source_sptr_name(*args)
-    def input_signature(*args): return _mc4020.mc4020_source_sptr_input_signature(*args)
-    def output_signature(*args): return _mc4020.mc4020_source_sptr_output_signature(*args)
-    def unique_id(*args): return _mc4020.mc4020_source_sptr_unique_id(*args)
-    def output_multiple(*args): return _mc4020.mc4020_source_sptr_output_multiple(*args)
-    def relative_rate(*args): return _mc4020.mc4020_source_sptr_relative_rate(*args)
-    def check_topology(*args): return _mc4020.mc4020_source_sptr_check_topology(*args)
-    def detail(*args): return _mc4020.mc4020_source_sptr_detail(*args)
-    def set_detail(*args): return _mc4020.mc4020_source_sptr_set_detail(*args)
+    def __deref__(*args): 
+        """__deref__(self)"""
+        return _mc4020.mc4020_source_sptr___deref__(*args)
+
+    def name(*args): 
+        """name(self) -> string"""
+        return _mc4020.mc4020_source_sptr_name(*args)
+
+    def input_signature(*args): 
+        """input_signature(self) -> gr_io_signature_sptr"""
+        return _mc4020.mc4020_source_sptr_input_signature(*args)
+
+    def output_signature(*args): 
+        """output_signature(self) -> gr_io_signature_sptr"""
+        return _mc4020.mc4020_source_sptr_output_signature(*args)
+
+    def unique_id(*args): 
+        """unique_id(self) -> long"""
+        return _mc4020.mc4020_source_sptr_unique_id(*args)
+
+    def output_multiple(*args): 
+        """output_multiple(self) -> int"""
+        return _mc4020.mc4020_source_sptr_output_multiple(*args)
+
+    def relative_rate(*args): 
+        """relative_rate(self) -> double"""
+        return _mc4020.mc4020_source_sptr_relative_rate(*args)
+
+    def check_topology(*args): 
+        """check_topology(self, int ninputs, int noutputs) -> bool"""
+        return _mc4020.mc4020_source_sptr_check_topology(*args)
+
+    def detail(*args): 
+        """detail(self) -> gr_block_detail_sptr"""
+        return _mc4020.mc4020_source_sptr_detail(*args)
+
+    def set_detail(*args): 
+        """set_detail(self, gr_block_detail_sptr detail)"""
+        return _mc4020.mc4020_source_sptr_set_detail(*args)
+
     def __del__(self, destroy=_mc4020.delete_mc4020_source_sptr):
+        """__del__(self)"""
         try:
             if self.thisown: destroy(self)
         except: pass
 
+
 class mc4020_source_sptrPtr(mc4020_source_sptr):
     def __init__(self, this):
         _swig_setattr(self, mc4020_source_sptr, 'this', this)
@@ -89,10 +132,20 @@ class mc4020_source_sptrPtr(mc4020_source_sptr):
 _mc4020.mc4020_source_sptr_swigregister(mc4020_source_sptrPtr)
 
 
-mc4020_source_block = _mc4020.mc4020_source_block
+def mc4020_source_block(*args):
+    """mc4020_source_block(mc4020_source_sptr r) -> gr_block_sptr"""
+    return _mc4020.mc4020_source_block(*args)
 mc4020_source_sptr.block = lambda self: mc4020_source_block (self)
 mc4020_source_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())
 
 
-source = _mc4020.source
+def source(*args):
+    """
+    source(double sampling_freq=20e6, unsigned long config_bitmask=0x00000001|(0x00000010|0x00000020|0x00000040|0x00000080), 
+        string dev="/dev/mc4020_0") -> mc4020_source_sptr
+    source(double sampling_freq=20e6, unsigned long config_bitmask=0x00000001|(0x00000010|0x00000020|0x00000040|0x00000080)) -> mc4020_source_sptr
+    source(double sampling_freq=20e6) -> mc4020_source_sptr
+    source() -> mc4020_source_sptr
+    """
+    return _mc4020.source(*args)
 
